pub fn bidiag_in_place<T: ComplexField>(
A: MatMut<'_, T>,
H_left: MatMut<'_, T>,
H_right: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
params: Spec<BidiagParams, T>,
)Expand description
computes a matrix $A$’s bidiagonalization such that $A = U B V^H$
$B$ is a bidiagonal matrix stored in $A$’s diagonal and superdiagonal
$U$ is a sequence of householder reflections stored in the unit lower triangular half of $A$,
with the householder coefficients being stored in H_left
$V$ is a sequence of householder reflections stored in the unit upper triangular half of $A$
(excluding the diagonal), with the householder coefficients being stored in H_right